##  Applying a Custom Design to a Workspace
You can align your workspace with your brand identity by applying a custom design. You can upload your menu logo, menu background image, and favicon, as well as adjust the colors of various UI elements to match your brand.
To apply a custom design to a workspace, follow these steps:
  1. In the administration area, navigate to the Branding section.
  2. On the branding settings page, in the Pre-Defined Designs section, select Custom.
  3. In the Custom Design section, adjust the settings for specific UI elements as needed. Changes are applied immediately and become visible to all workspace users as you’re modifying individual elements.


The following image shows an example workspace with a custom design applied.
![Example Workspace with a Custom Design](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750bf337a441014a851c151752120f0_LowRes.png)
Example Workspace with a Custom Design
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
